// JS Partials - Used in concat & uglify tasks
var jssrc = [
    // BOOTSTRAP
    'source/js/bootstrap/collapse.js',
    'source/js/bootstrap/dropdown.js',
    'source/js/bootstrap/modal.js',
    'source/js/bootstrap/tab.js',
    'source/js/bootstrap/transition.js',
    
    // THIRD PARTY LIBS
	'source/js/bootstrap-accessibility-plugin/functions.js',
    //'source/js/bootstrap-accessibility-plugin/collapse.js',
    'source/js/bootstrap-accessibility-plugin/dropdown.js',
    'source/js/bootstrap-accessibility-plugin/tab.js',
    'source/js/libs/responsive-tabs.js',
    'source/js/libs/owl.carousel.js',
    'source/js/libs/jquery.fancybox.js',
    'source/js/libs/jquery.eqheight.js',
    
    // CAGOV CORE
    'source/js/cagov/gatag.js',
    'source/js/cagov/navigation.js',
    'source/js/cagov/accordion.js',
    'source/js/cagov/panel.js',
    'source/js/cagov/search.js',
    'source/js/cagov/plugins.js',
    'source/js/cagov/gallery.js',
    'source/js/cagov/profile-banners.js',
    'source/js/cagov/carousel.js',
    'source/js/cagov/jobs.js',
    'source/js/cagov/locations.js',
    'source/js/cagov/socialsharer.js',
    'source/js/cagov/breadcrumb.js'
];

var csssrc = {
    "css/cagov.core.css": "source/less/cagov.core.less",
    "css/colorscheme-oceanside.css": "source/less/colorscheme-oceanside.less",
    "css/colorscheme-orangecounty.css": "source/less/colorscheme-orangecounty.less",
    "css/colorscheme-pasorobles.css": "source/less/colorscheme-pasorobles.less",
    "css/colorscheme-santabarbara.css": "source/less/colorscheme-santabarbara.less",
    "css/colorscheme-sierra.css": "source/less/colorscheme-sierra.less" 
}
            
module.exports = function (grunt) {

    grunt.initConfig({
		/* Load the package.json so we can use pkg variables */
		pkg: grunt.file.readJSON('package.json'),
        
        concat: {
          options: {
            banner: '<%= banner %><%= jqueryCheck %>',
            stripBanners: false
          },
          javascripts: {
            src: jssrc,
            dest: 'js/cagov.core.js'
          }
        },

        uglify: {
			my_target: {
			  files: {
				  'js/cagov.core.js': jssrc
			  }
			},
			options: {
    			// the banner is inserted at the top of the output
   				banner: '/* <%= pkg.name %> - v<%= pkg.version %> - <%= grunt.template.today("mmm-dd-yyyy") %> */\n/* JS COMPILED FROM SOURCE DO NOT MODIFY */\n'
 			}
		},
        
        less: {
          development: {
            options: {
              paths: ["css"],
              compress:false,
              ieCompat:true
            },
            files: csssrc
          },
          production: {
            options: {
              paths: ["css"],
              compress:true,
              ieCompat:true
            },
            files: csssrc
          }
        },
        		
        watch: {
            /* watch for less changes */
            less: {
                files: [
                  'source/less/*.less',
                  'source/less/bootstrap/*.less',
                  'source/less/bootstrap-accessibility-plugin/*.less',
                  'source/less/cagov/*.less',
                  'source/less/libs/*.less'
                ],
                tasks: 'less:development'
            },
			
			/* watch and see if our javascript files change, or new packages are installed */
			js: {
				files: [
                  'source/js/*.js',
                  'source/js/bootstrap/*.js',
                  'source/js/bootstrap-accessibility-plugin/*.js',
                  'source/js/libs/*.js',
                  'source/js/cagov/*.js'
                ],
				tasks: ['concat']
			},

            /* watch our files for change, reload */
            livereload: {
                files: ['*.html', '*.php', 'css/*.css', 'images/*', 'ssi/*.html', 'sample/*.html', 'sample/modules/*.html'],
                options: {
                	livereload: true
                }
            },
            
            /* Reload gruntfile if it changes */
            grunt: {
                files: ['Gruntfile.js']
            }

            /* Add new module here. Mind the comma's :) */
        }
    });
    
    // Use grunt to execute compass
    grunt.loadNpmTasks('grunt-contrib-less');

    // Use grunt to watch file changes.
    grunt.loadNpmTasks('grunt-contrib-watch');

    // Use uglify for js minification
    grunt.loadNpmTasks('grunt-contrib-uglify');
    
    // Concatenate js files 
    grunt.loadNpmTasks('grunt-contrib-concat');
    
    // Default task to watch and output uncompresses
    grunt.registerTask('default', ['watch']);
    
    // Build task to minify css and js
    grunt.registerTask('build', ['uglify', 'less:production']);
    
    // Development task to concat and unminify
    grunt.registerTask('dev', ['concat', 'less:development']);

};
